Installation — Django Categories v1.0b1 documentation

Django Categories v1.0b1 documentation

# Installation

- Table of Contents
- index
  next
  previous

# Installation

## To use the Category model

1. Install django-categories:

       pip install django-categories

2. Add `"categories"` and `"categories.editor"` to your `INSTALLED_APPS` list in your project’s `settings.py` file.

       INSTALLED_APPS = [
           # ...
           "categories",
           "categories.editor",
       ]

3. Run `./manage.py syncdb` (or `./manage.py migrate categories` if you are using South)

## To only subclass CategoryBase

If you are going to create your own models using `CategoryBase`, (see Creating Custom Categories) you’ll need a few different steps.

1. Install django-categories:

       pip install django-categories

2. Add `"categories.editor"` to your `INSTALLED_APPS` list in your project’s `settings.py` file.

       INSTALLED_APPS = [
           # ...
           "categories.editor",
       ]

3. Create your own models.